@@ -28,8 +28,8 @@
 #include "panel-util.h"
 #include "xstuff.h"
 #include "panel-globals.h"
-#include "panel-stock-icons.h"
 #include "panel-lockdown.h"
+#include "panel-icon-names.h"
 
 static void
 drawer_click (GtkWidget *w, Drawer *drawer)
@@ -242,10 +242,6 @@ close_drawer_in_idle (gpointer data)
 	drawer->close_timeout_id = 0;
 
 	if (drawer->opened_for_drag) {
-		PanelWidget *button_parent;
-
-		button_parent = PANEL_WIDGET (drawer->button->parent);
-
 		panel_toplevel_hide (drawer->toplevel, FALSE, -1);
 		drawer->opened_for_drag = FALSE;
 	}
@@ -339,13 +335,11 @@ create_drawer_applet (PanelToplevel    *toplevel,
 	drawer->toplevel = toplevel;
 
 	if (!use_custom_icon || !custom_icon || !custom_icon [0]) {
-		drawer->button = button_widget_new_from_stock (PANEL_STOCK_DRAWER,
-							       TRUE, orientation);
+		drawer->button = button_widget_new (PANEL_ICON_DRAWER, TRUE,
+						    orientation);
 	} else {
-		drawer->button = button_widget_new (custom_icon, TRUE, orientation);
-		/* make sure there is a backup stock id */
-		button_widget_set_stock_id (BUTTON_WIDGET (drawer->button),
-					    PANEL_STOCK_DRAWER);
+		drawer->button = button_widget_new (custom_icon, TRUE,
+						    orientation);
 	}
 
 	if (!drawer->button) {
@@ -478,8 +472,8 @@ panel_drawer_custom_icon_changed (GConfClient *client,
 
 		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, drawer->info->id, "use_custom_icon");
 		use_custom_icon = gconf_client_get_bool (client, key, NULL);
-		
-		button_widget_set_icon_name (BUTTON_WIDGET (drawer->button), custom_icon);
+		if (use_custom_icon)
+			button_widget_set_icon_name (BUTTON_WIDGET (drawer->button), custom_icon);
 	}
 }
 
@@ -489,13 +483,9 @@ panel_drawer_tooltip_changed (GConfClient *client,
 			      GConfEntry  *entry,
 			      Drawer      *drawer)
 {
-	const char *tooltip;
-
 	if (!entry->value || entry->value->type != GCONF_VALUE_STRING)
 		return;
 
-	tooltip = gconf_value_get_string (entry->value);
-
 	set_tooltip_and_name (drawer,
 			      gconf_value_get_string (entry->value));
 }
@@ -762,7 +752,10 @@ panel_drawer_set_dnd_enabled (Drawer   *drawer,
 				     GDK_BUTTON1_MASK,
 				     dnd_targets, 1,
 				     GDK_ACTION_MOVE);
-		gtk_drag_source_set_icon_stock (drawer->button, PANEL_STOCK_DRAWER);
+		//FIXME: we're forgetting the use_custom_icon case, here
+		gtk_drag_source_set_icon_name (drawer->button,
+					       button_widget_get_icon_name (BUTTON_WIDGET (drawer->button)));
+
 		GTK_WIDGET_SET_FLAGS (drawer->button, GTK_NO_WINDOW);
 
 	} else
