@@ -29,7 +29,6 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
-#include <libgnome/gnome-i18n.h>
 
 #include "menu.h"
 #include "applet.h"
@@ -52,14 +51,14 @@ panel_action_protocol_main_menu (GdkScreen *screen,
 	GtkWidget   *menu;
 	AppletInfo  *info;
 
-	info = panel_applet_get_by_type (PANEL_OBJECT_MENU_BAR);
+	info = panel_applet_get_by_type (PANEL_OBJECT_MENU_BAR, screen);
 	if (info) {
 		panel_menu_bar_popup_menu (PANEL_MENU_BAR (info->widget),
 					   activate_time);
 		return;
 	}
 
-	info = panel_applet_get_by_type (PANEL_OBJECT_MENU);
+	info = panel_applet_get_by_type (PANEL_OBJECT_MENU, screen);
 	if (info && !panel_menu_button_get_use_menu_path (PANEL_MENU_BUTTON (info->widget))) {
 		panel_menu_button_popup_menu (PANEL_MENU_BUTTON (info->widget),
 					      1, activate_time);
@@ -67,7 +66,7 @@ panel_action_protocol_main_menu (GdkScreen *screen,
 	}
 
 	panel_widget = panels->data;
-	menu = create_panel_root_menu (panel_widget);
+	menu = create_main_menu (panel_widget);
 
 	panel_toplevel_push_autohide_disabler (panel_widget->toplevel);
 
@@ -123,7 +122,7 @@ panel_action_protocol_init (void)
 	display = gdk_display_get_default ();
 
 	gdk_atom_gnome_panel_action =
-		gdk_atom_intern ("_GNOME_PANEL_ACTION", FALSE);
+		gdk_atom_intern_static_string ("_GNOME_PANEL_ACTION");
 
 	atom_gnome_panel_action =
 		XInternAtom (GDK_DISPLAY_XDISPLAY (display),
