@@ -2,7 +2,6 @@
 #define PANEL_UTIL_H
 
 #include <gtk/gtk.h>
-#include <libgnome/gnome-desktop-item.h>
 
 G_BEGIN_DECLS
 
@@ -13,15 +12,16 @@ typedef void (*UpdateFunction) (gpointer);
 
 #define		sure_string(s)		((const char *)((s)!=NULL?(s):""))
 
+void            panel_util_launch_from_key_file (GKeyFile                *keyfile,
+						 GList                   *file_list,
+						 GdkScreen               *screen,
+						 GError                 **error);
 void            panel_launch_desktop_file  (const char                   *desktop_file,
 					    const char                   *fallback_exec,
 					    GdkScreen                    *screen,
 					    GError                      **error);
-int             panel_ditem_launch         (GnomeDesktopItem             *item,
-					    GList                        *file_list,
-					    GnomeDesktopItemLaunchFlags   flags,
-					    GdkScreen                    *screen,
-					    GError                      **error);
+
+char *          panel_util_make_exec_uri_for_desktop (const char *exec);
 
 void		panel_show_help		(GdkScreen  *screen,
 					 const char *path,
@@ -45,12 +45,12 @@ GSList *panel_g_slist_make_unique (GSList       *list,
 				   GCompareFunc  compare,
 				   gboolean      free_data);
 
-GtkWidget      *panel_error_dialog      (GdkScreen  *screen,
+GtkWidget      *panel_error_dialog      (GtkWindow  *parent,
+					 GdkScreen  *screen,
 					 const char *class,
 					 gboolean    auto_destroy,
-					 const char *primary_format,
-					 const char *secondary_format,
-					 ...);
+					 const char *primary_text,
+					 const char *secondary_text);
 
 int		panel_find_applet_index	(GtkWidget *widget);
 
@@ -67,6 +67,7 @@ void            panel_lock_screen_action           (GdkScreen    *screen,
                                                     const char   *action);
 gboolean        panel_lock_screen_action_available (const char   *action);
 
+char *          panel_util_icon_remove_extension (const char *icon);
 char *          panel_find_icon         (GtkIconTheme  *icon_theme,
 					 const char    *icon_name,
 					 int            size);
@@ -76,12 +77,13 @@ GdkPixbuf *     panel_load_icon         (GtkIconTheme  *icon_theme,
 					 int            desired_width,
 					 int            desired_height,
 					 char         **error_msg);
-GdkPixbuf *	missing_pixbuf		(int size);
 
 char *panel_make_full_path   (const char *dir,
 			      const char *filename);
-char *panel_make_unique_uri (const char *dir,
-			     const char *suffix);
+char *panel_make_unique_desktop_path_from_name (const char *dir,
+						const char *name);
+char *panel_make_unique_desktop_uri (const char *dir,
+				     const char *source);
 char *panel_lookup_in_data_dirs (const char *basename);
 
 const char *panel_util_utf8_strstrcase (const char *haystack,
@@ -91,6 +93,44 @@ GdkPixbuf *panel_util_cairo_rgbdata_to_pixbuf (unsigned char *data,
 					       int            width,
 					       int            height);
 
+GKeyFile *panel_util_key_file_new_desktop  (void);
+gboolean  panel_util_key_file_to_file      (GKeyFile       *keyfile,
+					    const gchar    *file,
+					    GError        **error);
+gboolean panel_util_key_file_load_from_uri (GKeyFile       *keyfile,
+					    const gchar    *uri,
+					    GKeyFileFlags   flags,
+					    GError        **error);
+gboolean panel_util_key_file_get_boolean   (GKeyFile       *keyfile,
+					    const gchar    *key,
+					    gboolean        default_value);
+#define panel_util_key_file_get_string(key_file, key) \
+	 g_key_file_get_string (key_file, "Desktop Entry", key, NULL)
+#define panel_util_key_file_get_locale_string(key_file, key) \
+	 g_key_file_get_locale_string(key_file, "Desktop Entry", key, NULL, NULL)
+#define panel_util_key_file_set_boolean(key_file, key, value) \
+	 g_key_file_set_boolean (key_file, "Desktop Entry", key, value)
+#define panel_util_key_file_set_string(key_file, key, value) \
+	 g_key_file_set_string (key_file, "Desktop Entry", key, value)
+void    panel_util_key_file_set_locale_string (GKeyFile    *keyfile,
+					       const gchar *key,
+					       const gchar *value);
+#define panel_util_key_file_remove_key(key_file, key) \
+	g_key_file_remove_key (key_file, "Desktop Entry", key, NULL)
+void panel_util_key_file_remove_locale_key (GKeyFile    *keyfile,
+					    const gchar *key);
+void panel_util_key_file_remove_all_locale_key (GKeyFile    *keyfile,
+						const gchar *key);
+void panel_util_key_file_ensure_C_key (GKeyFile   *keyfile,
+				       const char *key);
+
+char *guess_icon_from_exec (GtkIconTheme *icon_theme,
+			    GKeyFile     *key_file);
+
+const char *panel_util_get_vfs_method_display_name (const char *method);
+char *panel_util_get_label_for_uri (const char *text_uri);
+char *panel_util_get_icon_for_uri (const char *text_uri);
+
 G_END_DECLS
 
 #endif /* PANEL_UTIL_H */
